@@ -1,4 +1,4 @@
-### Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+### Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
 ###
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -800,7 +800,7 @@ sub _ { return ::gettext($_[0]); }
       $self->echonl(sprintf(_('%s: Too few arguments.'), 'triggerenabled'));
       return undef;
     }
-    return $self->_objectenabled($trigger, 0, _('trigger'));
+    return $self->_objectenabled($trigger, 0);
   }
 
 
@@ -812,7 +812,7 @@ sub _ { return ::gettext($_[0]); }
       $self->echonl(sprintf(_('%s: Too few arguments.'), 'aliasenabled'));
       return undef;
     }
-    return $self->_objectenabled($alias, 1, _('alias'));
+    return $self->_objectenabled($alias, 1);
   }
 
 
@@ -824,7 +824,7 @@ sub _ { return ::gettext($_[0]); }
       $self->echonl(sprintf(_('%s: Too few arguments.'), 'macroenabled'));
       return undef;
     }
-    return $self->_objectenabled($macro, 2, _('macro'));
+    return $self->_objectenabled($macro, 2);
   }
 
 
@@ -836,20 +836,19 @@ sub _ { return ::gettext($_[0]); }
       $self->echonl(sprintf(_('%s: Too few arguments.'), 'timerenabled'));
       return undef;
     }
-    return $self->_objectenabled($timer, 3, _('timer'));
+    return $self->_objectenabled($timer, 3);
   }
 
 
   sub hookenabled {
     my $self  = shift;
-    my $event = shift;
-    my $hook  = shift;
+    my ($event, $hook) = @_;
 
-    if (!$event || !defined($hook)) {
+    if (!defined($event) || !defined($hook)) {
       $self->echonl(sprintf(_('%s: Too few arguments.'), 'hookenabled'));
       return undef;
     }
-    return $self->_objectenabled($hook, 4, _('hook'), $event);
+    return $self->_objectenabled($hook, 4, $event);
   }
 
 
