@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -438,11 +438,9 @@ insert_ansi_string(WorldGUI                    *gui,
   }
 
   /* Notify that text has been added. */
-  if (gui->world) {
-    operation = g_new(MainThreadOperation, 1);
-    operation->action = TEXT_ADDED;
-    operation_func(gui, operation);
-  }
+  operation = g_new(MainThreadOperation, 1);
+  operation->action = TEXT_ADDED;
+  operation_func(gui, operation);
 }
 
 
@@ -747,9 +745,7 @@ convert_vt100linedraw_string(WorldGUI     *gui,
     }
   }
 
-  gchar *converted_string = result->str;
-  g_string_free(result, FALSE);
-  return converted_string;
+  return g_string_free(result, FALSE);
 }
 
 
