@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -452,7 +452,7 @@ ansitextview_op_text_added(WorldGUI *gui, MainThreadOperation *operation)
   }
 
   /* Adjust unread markers */
-  if (!gui->world->has_focus && !gui->world->has_unread_text) {
+  if (gui->world && !gui->world->has_focus && !gui->world->has_unread_text) {
     gui->world->has_unread_text = TRUE;
     gtk_label_set_markup(gui->lblNotebook, gui->world->new_text_name);
     if (worlds_with_new_text != -1) {
