@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -202,10 +202,10 @@ create_cmd_history_dialog(GtkWindow *parent, World *world)
   if (!world->ui_builder) {
     world->ui_builder = gtk_builder_new();
   }
-  if (!gtk_builder_add_objects_from_file(world->ui_builder,
-                                         get_kildclient_installed_file("dlgCmdHistory.ui"),
-                                         objects,
-                                         &error)) {
+  if (!gtk_builder_add_objects_from_resource(world->ui_builder,
+                                             "/ekalin/kildclient/dlgCmdHistory.ui",
+                                             objects,
+                                             &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     return NULL; /* This will cause warnings in the calling function, but
@@ -432,10 +432,10 @@ cmdhistory_find_cb(GtkWidget *widget, gpointer data)
       gchar  *objects[] = { "dlgFind", NULL };
       GError *gerror    = NULL;
 
-      if (!gtk_builder_add_objects_from_file(world->ui_builder,
-                                             get_kildclient_installed_file("dlgCmdHistory.ui"),
-                                             objects,
-                                             &gerror)) {
+      if (!gtk_builder_add_objects_from_resource(world->ui_builder,
+                                                 "/ekalin/kildclient/dlgCmdHistory.ui",
+                                                 objects,
+                                                 &gerror)) {
         g_warning(_("Error loading UI from XML file: %s"), gerror->message);
         g_error_free(gerror);
         return;
