@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,9 +101,6 @@ XS_KCWin_feed(pTHX_ CV *perlcv)
 
   str = SvPV(ST(1), len);
 
-  /* TODO - KCWin is not working - this requires an operation Queue,
-     which it does not have.
-     Add string directly. */
   ansitextview_append_ansi_string_immediately(gui, str, len);
 
   XSRETURN_EMPTY;
