@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1223,7 +1223,7 @@ void do_multi_line_send(MLSendData *mlcontext, gdouble delay);
 /*********************************
  * Function prototypes - Network *
  *********************************/
-gboolean  connect_to(World *world, gchar **errmsg);
+void      connect_to(World *world);
 gboolean  disconnect_world_idle(gpointer data);
 void      disconnect_world(gpointer data, gboolean run_hook);
 gboolean  reconnect_world(gpointer data);
