@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,8 +101,13 @@ main(int argc, char *argv[], char *env[])
   opt_context = g_option_context_new(N_("[WORLD...]"));
   g_option_context_add_main_entries(opt_context, options, GETTEXT_PACKAGE);
   g_option_context_add_group(opt_context, gtk_get_option_group(TRUE));
-  g_option_context_parse(opt_context, &argc, &argv, &error);
+  if (!g_option_context_parse(opt_context, &argc, &argv, &error)) {
+    printf("%s\n", error->message);
+    g_error_free(error);
+    exit(1);
+  }
   g_option_context_free(opt_context);
+
   if (wants_version) {
     printf(PACKAGE_NAME " " PACKAGE_VERSION "\n");
     printf(_("Written by Eduardo M Kalinowski (eduardo@kalinowski.com.br)\n"));
