@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -156,9 +156,9 @@ create_main_window(WorldGUI *gui)
   GObject    *mnuQuit;
 
   main_builder = gtk_builder_new();
-  if (!gtk_builder_add_from_file(main_builder,
-                                 get_kildclient_installed_file("wndmain.ui"),
-                                 &error)) {
+  if (!gtk_builder_add_from_resource(main_builder,
+                                     "/ekalin/kildclient/wndmain.ui",
+                                     &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     exit(1); /* No point in continuing */
@@ -524,17 +524,12 @@ open_new_world(WorldGUI    *gui,
 {
   World    *world = NULL;
   gint      page = 0;
-  gint      action;
-  gchar    *errmsg = NULL;
-  World    *prev_world = NULL;
   gboolean  our_gui = FALSE;
 
   if (!gui) {
     gui = world_gui_new(TRUE);
     page = attach_world_gui(gui);
     our_gui = TRUE;
-  } else {
-    prev_world = gui->world;
   }
 
   if (cmdline_arg) {
@@ -547,38 +542,12 @@ open_new_world(WorldGUI    *gui,
     world->gui = gui;
     gui->world = world;
     ansitextview_update_color_tags(gui, gui->world);
-    while (1) {
-      if (connect_to(world, &errmsg)) {
-        set_focused_world(page);
-        world->has_focus      = TRUE;
-        world->is_current_tab = TRUE;
-        gtk_widget_grab_focus(GTK_WIDGET(world->gui->cmbEntry));
-        return TRUE;
-      } else {
-        action = disconnected_msgbox(errmsg, can_offline);
-        g_free(errmsg);
-        if (action == GTK_RESPONSE_CLOSE) {
-          break;
-        }
-        if (action == RESP_OFFLINE) {
-          *offline_selected = TRUE;
-          free_world(world);
-          gui->world = prev_world;
-          ansitextview_update_color_tags(gui, gui->world);
-          return TRUE;
-        }
-        if (action == RESP_OTHER) {
-          free_world(world);
-          world = get_world_to_connect();
-          if (!world) {
-            break;
-          }
-          world->gui = gui;
-          gui->world = world;
-          ansitextview_update_color_tags(gui, gui->world);
-        }
-      }
-    }
+    connect_to(world);
+    set_focused_world(page);
+    world->has_focus      = TRUE;
+    world->is_current_tab = TRUE;
+    gtk_widget_grab_focus(GTK_WIDGET(world->gui->cmbEntry));
+    return TRUE;
   }
 
   if (our_gui) {
@@ -625,9 +594,9 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
   GString    *timestr;
 
   ui_builder = gtk_builder_new();
-  if (!gtk_builder_add_from_file(ui_builder,
-                                 get_kildclient_installed_file("dlgStatistics.ui"),
-                                 &error)) {
+  if (!gtk_builder_add_from_resource(ui_builder,
+                                     "/ekalin/kildclient/dlgStatistics.ui",
+                                     &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     return;
@@ -725,7 +694,6 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
     GtkLabel                  *lblTLSCipher;
     GtkLabel                  *lblTLSMAC;
     GtkLabel                  *lblTLSKX;
-    GtkLabel                  *lblTLSComp;
     GtkLabel                  *lblTLSCertType;
     GtkLabel                  *lblTLSCertHostname;
     GtkLabel                  *lblTLSCertActivation;
@@ -761,10 +729,6 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
     val = gnutls_kx_get_name(gnutls_kx_get(currentWorld->tls_session));
     gtk_label_set_text(lblTLSKX, val);
 
-    lblTLSComp = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblTLSComp"));
-    val = gnutls_compression_get_name(gnutls_compression_get(currentWorld->tls_session));
-    gtk_label_set_text(lblTLSComp, val);
-
     lblTLSCertType = GTK_LABEL(gtk_builder_get_object(ui_builder,
                                                      "lblTLSCertType"));
     cert_type = gnutls_certificate_type_get(currentWorld->tls_session);
@@ -798,9 +762,28 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
         act_time = gnutls_x509_crt_get_activation_time(crt);
         exp_time = gnutls_x509_crt_get_expiration_time(crt);
 
+        now = time(NULL);
+        strftime(buf, MAX_BUFFER, "%c", localtime(&act_time));
+        if (act_time > now) {
+          strcat(buf, _(": Not yet active"));
+        }
+        gtk_label_set_text(lblTLSCertActivation, buf);
+        strftime(buf, MAX_BUFFER, "%c", localtime(&exp_time));
+        if (exp_time < now) {
+          strcat(buf, _(": Expired"));
+        }
+        gtk_label_set_text(lblTLSCertExpiration, buf);
+
         digest_size = sizeof(digest);
         gnutls_x509_crt_get_fingerprint(crt, GNUTLS_DIG_MD5,
                                         digest, &digest_size);
+        mval = buf;
+        for (i = 0; i < digest_size; i++) {
+          sprintf(mval, "%.2X:", (unsigned char) digest[i]);
+          mval += 3;
+        }
+        mval[strlen(mval) - 1] = 0; /* Remove last : */
+        gtk_label_set_text(lblTLSCertFingerprint, buf);
 
         size = sizeof(buf);
         gnutls_x509_crt_get_dn(crt, buf, &size);
@@ -826,26 +809,6 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
     }
     gtk_label_set_text(lblTLSCertHostname, mval);
     g_free(mval);
-
-    now = time(NULL);
-    strftime(buf, MAX_BUFFER, "%c", localtime(&act_time));
-    if (act_time > now) {
-      strcat(buf, _(": Not yet active"));
-    }
-    gtk_label_set_text(lblTLSCertActivation, buf);
-    strftime(buf, MAX_BUFFER, "%c", localtime(&exp_time));
-    if (exp_time < now) {
-      strcat(buf, _(": Expired"));
-    }
-    gtk_label_set_text(lblTLSCertExpiration, buf);
-
-    mval = buf;
-    for (i = 0; i < digest_size; i++) {
-      sprintf(mval, "%.2X:", (unsigned char) digest[i]);
-      mval += 3;
-    }
-    mval[strlen(mval) - 1] = 0; /* Remove last : */
-    gtk_label_set_text(lblTLSCertFingerprint, buf);
   } else {
     GtkLabel *lblTLS;
     lblTLS = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblTLS"));
@@ -891,9 +854,9 @@ menu_about_cb(GtkMenuItem *widget, gpointer data)
   static GtkAboutDialog *dlgAbout = NULL;
 
   if (!dlgAbout) {
-    if (!gtk_builder_add_from_file(main_builder,
-                                   get_kildclient_installed_file("dlgAbout.ui"),
-                                   &error)) {
+    if (!gtk_builder_add_from_resource(main_builder,
+                                       "/ekalin/kildclient/dlgAbout.ui",
+                                       &error)) {
       g_warning(_("Error loading UI from XML file: %s"), error->message);
       g_error_free(error);
       return;
