@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1913,9 +1913,8 @@ void
 XS__objectenabled(pTHX_ CV *perlcv)
 {
   /* Not to be called by user.
-     Arguments: name to match
+     Arguments: name or number of object to match
                 object type (0: trigger, 1: alias, 2: macro, 3: timer, 4:hook)
-                name of object
                 [optional] hook event name, if we are dealing with a hook
      Returns: TRUE/FALSE if object is enabled. If there are several with
               the same name, returns a list.
@@ -1949,7 +1948,7 @@ XS__objectenabled(pTHX_ CV *perlcv)
     break;
 
   case 4:
-    tofind = get_hook_list_or_warn_if_nonexistent(world, SvPV_nolen(ST(4)));
+    tofind = get_hook_list_or_warn_if_nonexistent(world, SvPV_nolen(ST(3)));
     if (!tofind) {
       XSRETURN(0);
     }
