@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,9 +100,9 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
   if (!dialog) {
     GError *error = NULL;
 
-    if (!gtk_builder_add_from_file(main_builder,
-                                   get_kildclient_installed_file("dlgPreferences.ui"),
-                                   &error)) {
+    if (!gtk_builder_add_from_resource(main_builder,
+                                       "/ekalin/kildclient/dlgPreferences.ui",
+                                       &error)) {
       g_warning(_("Error loading UI from XML file: %s"), error->message);
       g_error_free(error);
       return;
@@ -344,8 +344,7 @@ read_global_preferences_from(FILE *fp,
   char  first_word[MAX_BUFFER];
   int   pos;
 
-  fgets(line, MAX_BUFFER, fp);
-  while (!feof(fp)) {
+  while (fgets(line, MAX_BUFFER, fp)) {
     line[strlen(line) - 1] = '\0';  /* Remove newline at end */
     pos = strcspn(line, " ");
     memcpy(first_word, line, pos);
@@ -406,8 +405,6 @@ read_global_preferences_from(FILE *fp,
       fprintf(stderr,
               _("Unknown directive '%s' in config file.\n"), first_word);
     }
-
-    fgets(line, MAX_BUFFER, fp);
   }
 }
 
@@ -430,6 +427,7 @@ save_global_preferences(void)
     kc_error_dialog(GTK_WINDOW(wndMain),
                     _("Could not open file '%s': %s"),
                     filepath, error->message);
+    g_error_free(error);
   }
 
   g_free(filepath);
