@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,10 @@ play_sound(const gchar *file)
 
   to_run = g_strdup_printf(globalPrefs.audio_player_command, file);
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-result"
   system(to_run);
+#pragma GCC diagnostic pop
   g_free(to_run);
 }
 #else /* defined __MINGW32__ */
