@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -271,9 +271,9 @@ create_test_triggers_dialog(GtkWindow *parent, World *world)
   if (!world->ui_builder) {
     world->ui_builder = gtk_builder_new();
   }
-  if (!gtk_builder_add_from_file(world->ui_builder,
-                                 get_kildclient_installed_file("dlgTestTriggers.ui"),
-                                 &error)) {
+  if (!gtk_builder_add_from_resource(world->ui_builder,
+                                     "/ekalin/kildclient/dlgTestTriggers.ui",
+                                     &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     return NULL; /* This will cause warnings in the calling function, but
