@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,6 +92,9 @@ pango_font_to_css(const gchar *pango_font)
     case PANGO_VARIANT_SMALL_CAPS:
       g_string_append(s, "font-variant: small-caps; ");
       break;
+    default:
+      // Other attributes are not supported
+      break;
     }
   }
 
