@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,10 +69,10 @@ get_we_aliases_tab(World *world)
 
   /* Create the dialog */
   ui_builder = gtk_builder_new();
-  if (!gtk_builder_add_objects_from_file(ui_builder,
-                                         get_kildclient_installed_file("kildclient.ui"),
-                                         objects,
-                                         &error)) {
+  if (!gtk_builder_add_objects_from_resource(ui_builder,
+                                             "/ekalin/kildclient/kildclient.ui",
+                                             objects,
+                                             &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     return NULL; /* This will cause warnings in the calling function, but
@@ -448,10 +448,10 @@ edit_alias(World *world, Alias *alias)
   gboolean         need_recompute = FALSE;
 
   ui_builder = gtk_builder_new();
-  if (!gtk_builder_add_objects_from_file(ui_builder,
-                                         get_kildclient_installed_file("kildclient.ui"),
-                                         objects,
-                                         &error)) {
+  if (!gtk_builder_add_objects_from_resource(ui_builder,
+                                             "/ekalin/kildclient/kildclient.ui",
+                                             objects,
+                                             &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     return FALSE;
