@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,10 +74,10 @@ we_guied_export_cb(GtkButton *button, gpointer data)
   GtkWidget  *     filechooser;
 
   ui_builder = gtk_builder_new();
-  if (!gtk_builder_add_objects_from_file(ui_builder,
-                                         get_kildclient_installed_file("kildclient.ui"),
-                                         objects,
-                                         &error)) {
+  if (!gtk_builder_add_objects_from_resource(ui_builder,
+                                             "/ekalin/kildclient/kildclient.ui",
+                                             objects,
+                                             &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     return;
@@ -310,6 +310,7 @@ we_guied_do_export(World *world, const gchar *file, GtkBuilder *ui_builder)
     kc_error_dialog(GTK_WINDOW(world->dlgEditWorld),
                     _("Could not open file '%s': %s"),
                     file, error->message);
+    g_error_free(error);
   }
   g_string_free(file_contents, TRUE);
 }
@@ -392,6 +393,7 @@ we_guied_do_import(World *world, const gchar *filename)
     kc_error_dialog(GTK_WINDOW(world->dlgEditWorld),
                     _("Could not import file '%s': %s"),
                     filename, error->message);
+    g_error_free(error);
     free_world(newworld);
     return;
   }
