@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
   GtkSpinButton   *spnNLines;
   GtkToggleButton *chkAutoCompletion;
   GtkSpinButton   *spnMinPrefix;
-  GtkFontButton   *entryfont_btn;
+  GtkFontChooser  *entryfont_btn;
   GObject         *chkFloodPrevention;
   GtkWidget       *spnMaxCommands;
   GtkEntry        *txtPreventionCommand;
@@ -132,7 +132,7 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
   txtCommandSeparator
     = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtCommandSeparator"));
   entryfont_btn
-    = GTK_FONT_BUTTON(gtk_builder_get_object(ui_builder, "entryfont_btn"));
+    = GTK_FONT_CHOOSER(gtk_builder_get_object(ui_builder, "entryfont_btn"));
   chkFloodPrevention   = gtk_builder_get_object(ui_builder,
                                                 "chkFloodPrevention");
   spnMaxCommands
@@ -155,7 +155,7 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
 
   fill_spell_checking(world, ui_builder);
 
-  gtk_font_button_set_font_name(entryfont_btn, world->entryfont);
+  gtk_font_chooser_set_font(entryfont_btn, world->entryfont);
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkFloodPrevention),
                                world->flood_prevention);
@@ -189,7 +189,7 @@ fill_spell_checking(World *world, GtkBuilder *ui_builder)
     GtkTreeModel *model;
     GtkTreeIter   i;
     gboolean      has_more;
-    gboolean      found;
+    gboolean      found = FALSE;
     gint          index;
 
     model = gtk_combo_box_get_model(cmbSpellLanguage);
@@ -405,7 +405,8 @@ entryfont_set_cb(GtkFontButton *font_btn, gpointer data)
   WorldGUI *gui   = world->gui;
 
   free(world->entryfont);
-  world->entryfont = g_strdup(gtk_font_button_get_font_name(font_btn));
+  world->entryfont
+    = g_strdup(gtk_font_chooser_get_font(GTK_FONT_CHOOSER(font_btn)));
 
   if (gui) {
     configure_css(gui, world);
