@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ get_we_statusbar_tab(GtkBuilder *ui_builder)
 void
 fill_we_statusbar_tab(World *world, GtkBuilder *ui_builder)
 {
-  GtkFontButton   *statusfont_btn;
+  GtkFontChooser  *statusfont_btn;
   GtkToggleButton *radCTime_no;
   GtkToggleButton *radCTime_hms;
   GtkToggleButton *radCTime_sec;
@@ -68,9 +68,9 @@ fill_we_statusbar_tab(World *world, GtkBuilder *ui_builder)
   GtkToggleButton *radITime_sec;
   GtkToggleButton *chkResetActivate;
 
-  statusfont_btn = GTK_FONT_BUTTON(gtk_builder_get_object(ui_builder,
-                                                          "statusfont_btn"));
-  gtk_font_button_set_font_name(statusfont_btn, world->statusfont);
+  statusfont_btn = GTK_FONT_CHOOSER(gtk_builder_get_object(ui_builder,
+                                                           "statusfont_btn"));
+  gtk_font_chooser_set_font(statusfont_btn, world->statusfont);
 
   radCTime_no  = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder,
                                                           "radCTime_no"));
@@ -113,7 +113,7 @@ statusfont_set_cb(GtkFontButton *font_btn, gpointer data)
   WorldGUI *gui   = world->gui;
 
   free(world->statusfont);
-  world->statusfont = g_strdup(gtk_font_button_get_font_name(font_btn));
+  world->statusfont = g_strdup(gtk_font_chooser_get_font(GTK_FONT_CHOOSER(font_btn)));
 
   if (gui) {
     configure_css(gui, world);
