@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -160,6 +160,7 @@ world_gui_new(gboolean is_for_mud)
                NULL);
 
   gui->txtView = GTK_TEXT_VIEW(gtk_text_view_new());
+  gtk_widget_set_can_focus(GTK_WIDGET(gui->txtView), FALSE);
   add_css_provider_and_class(GTK_WIDGET(gui->txtView),
                              gui->css_provider, "mud-output");
   gtk_text_view_set_editable(gui->txtView, FALSE);
@@ -186,6 +187,7 @@ world_gui_new(gboolean is_for_mud)
                                    GTK_POLICY_ALWAYS);
     gui->txtViewScroll
       = GTK_TEXT_VIEW(gtk_text_view_new_with_buffer(gui->txtBuffer));
+    gtk_widget_set_can_focus(GTK_WIDGET(gui->txtViewScroll), FALSE);
     add_css_provider_and_class(GTK_WIDGET(gui->txtViewScroll),
                                gui->css_provider, "mud-output");
     gtk_text_view_set_editable(gui->txtViewScroll, FALSE);
@@ -317,14 +319,6 @@ world_gui_new(gboolean is_for_mud)
   }
   gtk_box_pack_start(GTK_BOX(gui->vbox), gui->commandArea, FALSE, FALSE, 0);
 
-  /* Keep the focus always in the entry box */
-  g_signal_connect_swapped(G_OBJECT(gui->txtView), "focus-in-event",
-                           G_CALLBACK(gtk_widget_grab_focus), gui->cmbEntry);
-  if (is_for_mud) {
-    g_signal_connect_swapped(G_OBJECT(gui->txtViewScroll), "focus-in-event",
-                             G_CALLBACK(gtk_widget_grab_focus), gui->cmbEntry);
-  }
-
   /* Set initial colors and state */
   gui->ta_state.fg_color = gui->saved_ta_state.fg_color
     = ANSI_DEFAULT_COLOR_IDX;
@@ -521,7 +515,7 @@ worldgui_determine_supported_chars(WorldGUI *gui)
   gui->ta.sup_greek         = pango_coverage_get(coverage, 0x03C0);
 
   pango_font_description_free(fontdesc);
-  pango_coverage_unref(coverage);
+  g_object_unref(coverage);
 }
 
 
@@ -1122,9 +1116,9 @@ act_if_link(WorldGUI *gui, GtkTextIter *iter,
     GtkMenu    *mnuPopupURL;
 
     ui_builder = gtk_builder_new();
-    if (!gtk_builder_add_from_file(ui_builder,
-                                   get_kildclient_installed_file("mnuPopupURL.ui"),
-                                   &error)) {
+    if (!gtk_builder_add_from_resource(ui_builder,
+                                       "/ekalin/kildclient/mnuPopupURL.ui",
+                                       &error)) {
       g_warning(_("Error loading UI from XML file: %s"), error->message);
       g_error_free(error);
       return TRUE;
@@ -1151,7 +1145,7 @@ menu_url_open(GtkMenuItem *menu, char *url)
 
   gtk_show_uri_on_window(GTK_WINDOW(wndMain), url, GDK_CURRENT_TIME, &err);
   if (err != NULL) {
-    fprintf(stderr, "Error opening URL: %s\nCheck if gvfs is installed\n",
+    fprintf(stderr, _("Error opening URL: %s\n"),
             err->message);
     g_error_free(err);
   }
