@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -2345,6 +2345,7 @@ save_world_to_file(World *world)
     kc_error_dialog(GTK_WINDOW(wndMain),
                     _("Could not open file '%s': %s"),
                     world->file, error->message);
+    g_error_free(error);
   }
   g_string_free(file_contents, TRUE);
 }
@@ -2376,8 +2377,7 @@ load_command_history(World *world)
 
   liststore = GTK_LIST_STORE(world->cmd_list);
 
-  fgets(command, MAX_BUFFER, fp);
-  while (!feof(fp)) {
+  while (fgets(command, MAX_BUFFER, fp)) {
     command[strlen(command) - 1] = '\0'; /* Strip final newline */
 
     gtk_list_store_append(liststore, &iter);
@@ -2386,8 +2386,6 @@ load_command_history(World *world)
                        CMDLIST_COL_TENTATIVE, NULL,
                        -1);
     ++world->cmd_list_size;
-
-    fgets(command, MAX_BUFFER, fp);
   }
 
   fclose(fp);
