@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2017 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2023 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -134,6 +134,7 @@ get_world_to_connect()
             kc_error_dialog(GTK_WINDOW(wndMain),
                             _("Could not load world from file '%s': %s"),
                             file, error->message);
+            g_error_free(error);
             free_world(world);
             world = NULL;
           } else {
@@ -180,9 +181,9 @@ create_world_selector_dlg(GtkWindow* parent)
   GtkTreeIter       *last_open_iter = NULL;
 
   ui_builder = gtk_builder_new();
-  if (!gtk_builder_add_from_file(ui_builder,
-                                 get_kildclient_installed_file("dlgSelectWorld.ui"),
-                                 &error)) {
+  if (!gtk_builder_add_from_resource(ui_builder,
+                                     "/ekalin/kildclient/dlgSelectWorld.ui",
+                                     &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
     exit(1); /* No point in continuing */
@@ -352,6 +353,7 @@ add_saved_worlds_model_entry_from_file(GtkTreeStore *model,
   if (!load_world_from_file(file, world, TRUE, &error)) {
     fprintf(stderr, "Error loading %s: %s\n",
             file, error->message);
+    g_error_free(error);
     return;
   }
 
@@ -486,6 +488,7 @@ get_world_from_cmdline(const gchar *cmdline)
       g_free(world_file);
       fprintf(stderr, _("Could not open world '%s': %s\n"),
               cmdline, error->message);
+      g_error_free(error);
       free_world(world);
     }
   } else {
@@ -495,7 +498,7 @@ get_world_from_cmdline(const gchar *cmdline)
     gchar      *user;
     gchar      *password;
 
-    GError *error;
+    GError *error = NULL;
     if (parameters_regex == NULL) {
       parameters_regex = g_regex_new(
         "^(telnet://)?"
@@ -510,6 +513,7 @@ get_world_from_cmdline(const gchar *cmdline)
         &error);
       if (error) {
         fputs(error->message, stderr);
+        g_error_free(error);
       }
     }
 
@@ -676,6 +680,7 @@ add_edit_buttons_cb(GtkButton *btn, gpointer data)
       kc_error_dialog(GTK_WINDOW(wndMain),
                       _("Could not load world from file '%s': %s"),
                       file, error->message);
+      g_error_free(error);
       g_free(world);
       return;
     }
